@@ -6,12 +6,10 @@ from .converters import (
     human_readable_to_markdown,
     markdown_to_pdf
 )
-from .ai_support import AISupport  # 追加
 from .validator import Validator  # 追加
 
 __all__ = [
     "LinguStruct",
-    "AISupport",
     "Validator",
     "lingu_struct_to_human_readable",
     "human_readable_to_lingu_struct",
@@ -19,4 +17,3 @@ __all__ = [
     "human_readable_to_markdown",
     "markdown_to_pdf"
 ]
-
